@@ -1,3 +1,5 @@
+sudo cp demo/aminerRemoteControl/demo-config.py /tmp/demo-config.py
+sudo sed -i 's/StreamPrinterEventHandler(analysis_context)/StreamPrinterEventHandler(analysis_context, stream=open("\/tmp\/log.txt", "a"))/g' /tmp/demo-config.py
 sudo mkdir /tmp/lib 2> /dev/null
 sudo mkdir /tmp/lib/aminer 2> /dev/null
 sudo mkdir /tmp/lib/aminer/log 2> /dev/null
@@ -6,7 +8,7 @@ sudo chown -R aminer:aminer /tmp/lib 2> /dev/null
 sudo rm /tmp/syslog 2> /dev/null
 touch /tmp/syslog
 
-FILE=demo/AMinerRemoteControl/demo-config.py
+FILE=/tmp/demo-config.py
 sudo aminer --config "$FILE" & > /dev/null
 
 sleep 1
@@ -128,7 +130,7 @@ for property in "${INTEGER_CONFIG_PROPERTIES[@]}"; do
   expected="$PREFIX\"FAILURE: the value of the property $property must be of type <class 'int'>!\""
   expected_list="${expected_list}${expected}
 "
-  if [[ "$stdout" != "$expected" && "$stdout" != "$PREFIX'FAILURE: it is not safe to run the AMiner with less than 32MB RAM.'" ]]; then
+  if [[ "$stdout" != "$expected" && "$stdout" != "$PREFIX'FAILURE: it is not safe to run the aminer with less than 32MB RAM.'" ]]; then
 	  echo "$ERROR changing $property wrong Type."
 	  echo "$stdout"
 	  echo "Expected: $expected"
@@ -138,14 +140,14 @@ for property in "${INTEGER_CONFIG_PROPERTIES[@]}"; do
   echo "change_config_property(analysis_context, $property, 1)" >> /tmp/commands.txt
   stdout=$(sudo aminerremotecontrol --exec "change_config_property(analysis_context, $property, 1)")
   expected="$PREFIX\"$property changed to '1' successfully.\""
-  if [[ "$stdout" == "$PREFIX'FAILURE: it is not safe to run the AMiner with less than 32MB RAM.'" ]]; then
+  if [[ "$stdout" == "$PREFIX'FAILURE: it is not safe to run the aminer with less than 32MB RAM.'" ]]; then
     expected_list="${expected_list}${stdout}
 "
   else
     expected_list="${expected_list}${expected}
 "
   fi
-  if [[ "$stdout" != "$expected" && "$stdout" != "$PREFIX'FAILURE: it is not safe to run the AMiner with less than 32MB RAM.'" ]]; then
+  if [[ "$stdout" != "$expected" && "$stdout" != "$PREFIX'FAILURE: it is not safe to run the aminer with less than 32MB RAM.'" ]]; then
 	    echo "$ERROR changing $property to 1."
 	    echo "$stdout"
 	    echo "Expected: $expected"
@@ -562,6 +564,20 @@ stdout=$(echo "$stdout" | sed -e "s/\"next_persist_time\".*,//")
 expected_list="${expected_list}${stdout}
 "
 
+echo "reopen_event_handler_streams(analysis_context)" >> /tmp/commands.txt
+stdout=$(sudo aminerremotecontrol --exec "reopen_event_handler_streams(analysis_context)")
+expected="$PREFIX'Reopened all StreamPrinterEventHandler streams.'"
+if [[ "$stdout" != "$expected" ]]; then
+	echo "$ERROR reopen_event_handler_streams had an execution error."
+	echo "$stdout"
+	echo "Expected: $expected"
+	echo
+	exit_code=1
+fi
+stdout=$(echo "$stdout" | sed -e "s/\"next_persist_time\".*,//")
+expected_list="${expected_list}${stdout}
+"
+
 sudo pkill -x aminer
 sleep 2 & wait $!
 sudo mkdir /tmp/lib 2> /dev/null
