@@ -1,9 +1,16 @@
 import time
 
 from aminer.analysis.NewMatchIdValueComboDetector import NewMatchIdValueComboDetector
-from aminer.input import LogAtom
-from aminer.parsing import FirstMatchModelElement, SequenceModelElement, FixedDataModelElement, DelimitedDataModelElement, \
-    DecimalIntegerValueModelElement, FixedWordlistDataModelElement, AnyByteDataModelElement, MatchContext, ParserMatch
+from aminer.input.LogAtom import LogAtom
+from aminer.parsing.FirstMatchModelElement import FirstMatchModelElement
+from aminer.parsing.SequenceModelElement import SequenceModelElement
+from aminer.parsing.FixedDataModelElement import FixedDataModelElement
+from aminer.parsing.DelimitedDataModelElement import DelimitedDataModelElement
+from aminer.parsing.DecimalIntegerValueModelElement import DecimalIntegerValueModelElement
+from aminer.parsing.FixedWordlistDataModelElement import FixedWordlistDataModelElement
+from aminer.parsing.AnyByteDataModelElement import AnyByteDataModelElement
+from aminer.parsing.MatchContext import MatchContext
+from aminer.parsing.ParserMatch import ParserMatch
 from unit.TestBase import TestBase
 
 
@@ -74,7 +81,8 @@ class NewMatchIdValueComboDetectorTest(TestBase):
         FixedDataModelElement('name_string', b' name="'), DelimitedDataModelElement('name', b'"'),
         FixedDataModelElement('inode_string', b'" inode='), DecimalIntegerValueModelElement('inode'),
         FixedDataModelElement('dev_string', b' dev='), DelimitedDataModelElement('dev', b' '),
-        FixedDataModelElement('mode_string', b' mode='), DecimalIntegerValueModelElement('mode'),
+        FixedDataModelElement('mode_string', b' mode='), DecimalIntegerValueModelElement(
+            'mode', value_pad_type=DecimalIntegerValueModelElement.PAD_TYPE_ZERO),
         FixedDataModelElement('ouid_string', b' ouid='), DecimalIntegerValueModelElement('ouid'),
         FixedDataModelElement('ogid_string', b' ogid='), DecimalIntegerValueModelElement('ogid'),
         FixedDataModelElement('rdev_string', b' rdev='), DelimitedDataModelElement('rdev', b' '),
