@@ -2,35 +2,44 @@
 
 # if set to 1 this installer will delete the 
 # source directory after installation
-DELDIR=0
+DELDIR=1
 BRANCH="main"
 URL="https://github.com/ait-aecid/logdata-anomaly-miner.git"
+AMINERSRC=`mktemp -d`
+
+help() {
+	echo "Usage: $0 [-h] [-b BRANCH] [-u GITURL] [-d DIRECTORY]" 1>&2
+}
 
 
-if [ $# -gt 0 ]
-then
-	if [ "$1" == "-h" ]
-	then
-		echo "$0 [<giturl>] [<aminer-dir>]"
-		exit 1
-	fi
-	URL="$1"
-	if [ $# -eq 2 ]
-	then
-		AMINERSRC="$2"
-	else
-		AMINERSRC=$(pwd)/logdata-anomaly-miner
-	fi
-	BRANCH="development"
-	if [ -d $AMINERSRC ]
-	then
-		echo "This directory($AMINERSRC) already exists. Please remove it first"
-		exit 1
-	fi
-else
-	AMINERSRC=`mktemp -d`
-	DELDIR=1
-fi
+while getopts "hb:u:d:" options; do
+	case "${options}" in
+		b)
+			BRANCH=${OPTARG}
+			;;
+		h)
+			help
+			exit 1
+			;;
+		u)
+			URL=${OPTARG}
+			;;
+		d)
+			AMINERSRC=${OPTARG}
+			if [ -d $AMINERSRC ]
+			then
+				echo "This directory($AMINERSRC) already exists. Please remove it first"
+				exit 1
+			fi
+			DELDIR=0
+			;;
+		:)
+			echo "$0: Must supply an argument to -$OPTARG." >&2
+			exit 1
+			;;
+	esac
+done
+
 
 if [ -e /etc/debian_version ]
 then
