@@ -57,11 +57,12 @@ import abc
 import logging
 from datetime import datetime
 
-from aminer import AMinerConfig
+from aminer.AminerConfig import build_persistence_file_name, DEBUG_LOG_NAME, KEY_PERSISTENCE_PERIOD, DEFAULT_PERSISTENCE_PERIOD
+from aminer import AminerConfig
 from aminer.AnalysisChild import AnalysisContext
-from aminer.input import AtomHandlerInterface
+from aminer.input.InputInterfaces import AtomHandlerInterface
 from aminer.util import PersistenceUtil
-from aminer.util import TimeTriggeredComponentInterface
+from aminer.util.TimeTriggeredComponentInterface import TimeTriggeredComponentInterface
 
 binomial_test = None
 try:
@@ -175,9 +176,8 @@ class LinearNumericBinDefinition(BinDefinition):
         """
         if binomial_test is None:
             return None
-        if self.outlier_bins_flag:
-            if (bin_pos == 0) or (bin_pos > self.bin_count):
-                return None
+        if self.outlier_bins_flag and (bin_pos == 0 or bin_pos > self.bin_count):
+            return None
         return binomial_test(bin_values, total_values, self.expected_bin_ratio)
 
 
@@ -207,7 +207,7 @@ class ModuloTimeBinDefinition(LinearNumericBinDefinition):
         return super(ModuloTimeBinDefinition, self).get_bin(time_value)
 
 
-class HistogramData():
+class HistogramData:
     """
     This class defines the properties of one histogram to create and performs the accounting and reporting.
     When the Python scipy package is available, reports will also include probability score created using binomial testing.
@@ -254,8 +254,7 @@ class HistogramData():
         result = '%sProperty "%s" (%d elements):' % (indent, self.property_path, self.total_elements)
         f_elements = float(self.total_elements)
         base_element = self.binned_elements if self.has_outlier_bins_flag else self.total_elements
-        for bin_pos in range(0, len(self.bin_data)):
-            count = self.bin_data[bin_pos]
+        for bin_pos, count in enumerate(self.bin_data):
             if count == 0:
                 continue
             p_value = self.bin_definition.get_bin_p_value(bin_pos, base_element, count)
@@ -292,12 +291,12 @@ class HistogramAnalysis(AtomHandlerInterface, TimeTriggeredComponentInterface):
         self.output_log_line = output_log_line
         self.aminer_config = aminer_config
 
+        self.persistence_file_name = build_persistence_file_name(aminer_config, self.__class__.__name__, persistence_id)
         PersistenceUtil.add_persistable_component(self)
-        self.persistenceFileName = AMinerConfig.build_persistence_file_name(aminer_config, 'HistogramAnalysis', persistence_id)
-        persistence_data = PersistenceUtil.load_json(self.persistenceFileName)
+        persistence_data = PersistenceUtil.load_json(self.persistence_file_name)
         if persistence_data is not None:
             msg = 'No data reading, def merge yet'
-            logging.getLogger(AMinerConfig.DEBUG_LOG_NAME).error(msg)
+            logging.getLogger(DEBUG_LOG_NAME).error(msg)
             raise Exception(msg)
 
     def receive_atom(self, log_atom):
@@ -325,9 +324,10 @@ class HistogramAnalysis(AtomHandlerInterface, TimeTriggeredComponentInterface):
 
         if self.next_persist_time is None and data_updated_flag:
             self.next_persist_time = time.time() + self.aminer_config.config_properties.get(
-                AMinerConfig.KEY_PERSISTENCE_PERIOD, AMinerConfig.DEFAULT_PERSISTENCE_PERIOD)
+                KEY_PERSISTENCE_PERIOD, DEFAULT_PERSISTENCE_PERIOD)
 
-    def get_time_trigger_class(self):
+    @staticmethod
+    def get_time_trigger_class():
         """
         Get the trigger class this component should be registered for.
         This trigger is used only for persistence, so real-time triggering is needed.
@@ -337,18 +337,18 @@ class HistogramAnalysis(AtomHandlerInterface, TimeTriggeredComponentInterface):
     def do_timer(self, trigger_time):
         """Check current ruleset should be persisted."""
         if self.next_persist_time is None:
-            return self.aminer_config.config_properties.get(AMinerConfig.KEY_PERSISTENCE_PERIOD, AMinerConfig.DEFAULT_PERSISTENCE_PERIOD)
+            return self.aminer_config.config_properties.get(KEY_PERSISTENCE_PERIOD, DEFAULT_PERSISTENCE_PERIOD)
 
         delta = self.next_persist_time - trigger_time
         if delta < 0:
             self.do_persist()
-            delta = self.aminer_config.config_properties.get(AMinerConfig.KEY_PERSISTENCE_PERIOD, AMinerConfig.DEFAULT_PERSISTENCE_PERIOD)
+            delta = self.aminer_config.config_properties.get(KEY_PERSISTENCE_PERIOD, DEFAULT_PERSISTENCE_PERIOD)
         return delta
 
     def do_persist(self):
         """Immediately write persistence data to storage."""
         self.next_persist_time = None
-        logging.getLogger(AMinerConfig.DEBUG_LOG_NAME).debug('%s persisted data.', self.__class__.__name__)
+        logging.getLogger(DEBUG_LOG_NAME).debug('%s persisted data.', self.__class__.__name__)
 
     def send_report(self, log_atom, timestamp):
         """Send a report to the event handlers."""
@@ -357,7 +357,7 @@ class HistogramAnalysis(AtomHandlerInterface, TimeTriggeredComponentInterface):
             report_str += 'from %s ' % datetime.fromtimestamp(self.last_report_time).strftime(date_string)
         report_str += 'till %s' % datetime.fromtimestamp(timestamp).strftime(date_string)
         affected_log_atom_paths = []
-        analysis_component = {'AffectedLogAtomPathes': affected_log_atom_paths}
+        analysis_component = {'AffectedLogAtomPaths': affected_log_atom_paths}
         for histogramData in self.histogram_data:
             affected_log_atom_paths.append(histogramData.property_path)
         res = []
@@ -387,7 +387,7 @@ class HistogramAnalysis(AtomHandlerInterface, TimeTriggeredComponentInterface):
                 for match_path, match_element in log_atom.parser_match.get_match_dictionary().items():
                     match_value = match_element.match_object
                     if isinstance(match_value, bytes):
-                        match_value = match_value.decode()
+                        match_value = match_value.decode(AminerConfig.ENCODING)
                     match_paths_values[match_path] = match_value
                 analysis_component['ParsedLogAtom'] = match_paths_values
             d['PropertyPath'] = data_item.property_path
@@ -409,13 +409,13 @@ class HistogramAnalysis(AtomHandlerInterface, TimeTriggeredComponentInterface):
 
         self.last_report_time = timestamp
         self.next_report_time = timestamp + self.report_interval
-        logging.getLogger(AMinerConfig.DEBUG_LOG_NAME).debug('%s sent report.', self.__class__.__name__)
+        logging.getLogger(DEBUG_LOG_NAME).debug('%s sent report.', self.__class__.__name__)
 
 
 class PathDependentHistogramAnalysis(AtomHandlerInterface, TimeTriggeredComponentInterface):
     """
-    This class provides a histogram analysis for only one property but separate histograms for each group of correlated match pathes.
-    Assume there two pathes that include the requested property but they separate after the property was found on the path.
+    This class provides a histogram analysis for only one property but separate histograms for each group of correlated match paths.
+    Assume there two paths that include the requested property but they separate after the property was found on the path.
     Then objects of this class will produce 3 histograms: one for common path part including all occurences of the target property
     and one for each separate subpath, counting only those property values where the specific subpath was followed.
     """
@@ -440,13 +440,12 @@ class PathDependentHistogramAnalysis(AtomHandlerInterface, TimeTriggeredComponen
         self.output_log_line = output_log_line
         self.aminer_config = aminer_config
 
+        self.persistence_file_name = build_persistence_file_name(aminer_config, self.__class__.__name__, persistence_id)
         PersistenceUtil.add_persistable_component(self)
-        self.persistence_file_name = AMinerConfig.build_persistence_file_name(aminer_config, 'PathDependentHistogramAnalysis',
-                                                                              persistence_id)
         persistence_data = PersistenceUtil.load_json(self.persistence_file_name)
         if persistence_data is not None:
             msg = 'No data reading, def merge yet'
-            logging.getLogger(AMinerConfig.DEBUG_LOG_NAME).error(msg)
+            logging.getLogger(DEBUG_LOG_NAME).error(msg)
             raise Exception(msg)
 
     def receive_atom(self, log_atom):
@@ -467,7 +466,7 @@ class PathDependentHistogramAnalysis(AtomHandlerInterface, TimeTriggeredComponen
             if histogram_mapping is None:
                 unmapped_path.append(path)
                 continue
-            # So the path is already mapped to one histogram. See if all pathes
+            # So the path is already mapped to one histogram. See if all paths
             # to the given histogram are still in all_path_set. If not, a split
             # within the mapping is needed.
             clone_set = all_path_set.copy()
@@ -484,14 +483,13 @@ class PathDependentHistogramAnalysis(AtomHandlerInterface, TimeTriggeredComponen
                 match = match_dict.get(mapped_path, None)
                 match_value = match.match_object
                 if isinstance(match.match_object, bytes):
-                    match.match_object = match.match_object.decode()
+                    match.match_object = match.match_object.decode(AminerConfig.ENCODING)
                 histogram_mapping[1].property_path = mapped_path
                 histogram_mapping[1].add_value(match_value)
                 histogram_mapping[2] = log_atom.parser_match
             else:
-                # We need to split the current set here. Keep the current statistics
-                # for all the missingPathes but clone the data for the remaining
-                # pathes.
+                # We need to split the current set here. Keep the current statistics for all the missingPaths but clone the data for the
+                # remaining paths.
                 new_histogram = histogram_mapping[1].clone()
                 match = match_dict.get(mapped_path, None)
                 match_value = match.match_object
@@ -524,10 +522,11 @@ class PathDependentHistogramAnalysis(AtomHandlerInterface, TimeTriggeredComponen
 
         if self.next_persist_time is None:
             self.next_persist_time = time.time() + self.aminer_config.config_properties.get(
-                AMinerConfig.KEY_PERSISTENCE_PERIOD, AMinerConfig.DEFAULT_PERSISTENCE_PERIOD)
+                KEY_PERSISTENCE_PERIOD, DEFAULT_PERSISTENCE_PERIOD)
         self.log_success += 1
 
-    def get_time_trigger_class(self):
+    @staticmethod
+    def get_time_trigger_class():
         """
         Get the trigger class this component should be registered for.
         This trigger is used only for persistence, so real-time triggering is needed.
@@ -537,18 +536,18 @@ class PathDependentHistogramAnalysis(AtomHandlerInterface, TimeTriggeredComponen
     def do_timer(self, trigger_time):
         """Check current ruleset should be persisted."""
         if self.next_persist_time is None:
-            return self.aminer_config.config_properties.get(AMinerConfig.KEY_PERSISTENCE_PERIOD, AMinerConfig.DEFAULT_PERSISTENCE_PERIOD)
+            return self.aminer_config.config_properties.get(KEY_PERSISTENCE_PERIOD, DEFAULT_PERSISTENCE_PERIOD)
 
         delta = self.next_persist_time - trigger_time
         if delta < 0:
             self.do_persist()
-            delta = self.aminer_config.config_properties.get(AMinerConfig.KEY_PERSISTENCE_PERIOD, AMinerConfig.DEFAULT_PERSISTENCE_PERIOD)
+            delta = self.aminer_config.config_properties.get(KEY_PERSISTENCE_PERIOD, DEFAULT_PERSISTENCE_PERIOD)
         return delta
 
     def do_persist(self):
         """Immediately write persistence data to storage."""
         self.next_persist_time = None
-        logging.getLogger(AMinerConfig.DEBUG_LOG_NAME).debug('%s persisted data.', self.__class__.__name__)
+        logging.getLogger(DEBUG_LOG_NAME).debug('%s persisted data.', self.__class__.__name__)
 
     def send_report(self, log_atom, timestamp):
         """Send report to event handlers."""
@@ -581,7 +580,7 @@ class PathDependentHistogramAnalysis(AtomHandlerInterface, TimeTriggeredComponen
                     if isinstance(match_value, datetime):
                         match_value = match_value.timestamp()
                     if isinstance(match_value, bytes):
-                        match_value = match_value.decode()
+                        match_value = match_value.decode(AminerConfig.ENCODING)
                     match_paths_values[match_path] = match_value
                 analysis_component['ParsedLogAtom'] = match_paths_values
                 bin_definition = {
@@ -596,7 +595,8 @@ class PathDependentHistogramAnalysis(AtomHandlerInterface, TimeTriggeredComponen
             d['PropertyPath'] = data_item.property_path
             report_str += os.linesep + 'Path values "%s":' % '", "'.join(histogram_mapping[0])
             if isinstance(histogram_mapping[2].match_element.match_string, bytes):
-                histogram_mapping[2].match_element.match_string = histogram_mapping[2].match_element.match_string.decode()
+                histogram_mapping[2].match_element.match_string = histogram_mapping[2].match_element.match_string.decode(
+                    AminerConfig.ENCODING)
             report_str += os.linesep + 'Example: %s' % histogram_mapping[2].match_element.match_string
             if len(res) < histogram_mapping[1].total_elements:
                 res = [''] * histogram_mapping[1].total_elements
@@ -619,4 +619,4 @@ class PathDependentHistogramAnalysis(AtomHandlerInterface, TimeTriggeredComponen
 
         self.last_report_time = timestamp
         self.next_report_time = timestamp + self.report_interval
-        logging.getLogger(AMinerConfig.DEBUG_LOG_NAME).debug('%s sent report.', self.__class__.__name__)
+        logging.getLogger(DEBUG_LOG_NAME).debug('%s sent report.', self.__class__.__name__)
