@@ -14,31 +14,32 @@ this program. If not, see <http://www.gnu.org/licenses/>.
 import time
 import logging
 
-from aminer import AMinerConfig
-from aminer.AMinerConfig import STAT_LEVEL, STAT_LOG_NAME
+from aminer.AminerConfig import build_persistence_file_name, DEBUG_LOG_NAME, KEY_PERSISTENCE_PERIOD, DEFAULT_PERSISTENCE_PERIOD,\
+    STAT_LOG_NAME
+from aminer import AminerConfig
 from aminer.AnalysisChild import AnalysisContext
-from aminer.events import EventSourceInterface
-from aminer.input import AtomHandlerInterface
+from aminer.events.EventInterfaces import EventSourceInterface
+from aminer.input.InputInterfaces import AtomHandlerInterface
 from aminer.util import PersistenceUtil
-from aminer.util import TimeTriggeredComponentInterface
+from aminer.util.TimeTriggeredComponentInterface import TimeTriggeredComponentInterface
 
 
 class MissingMatchPathValueDetector(AtomHandlerInterface, TimeTriggeredComponentInterface, EventSourceInterface):
     """
     This class creates events when an expected value is not seen within a given timespan.
     For example because the service was deactivated or logging disabled unexpectedly. This is complementary to the function provided by
-    NewMatchPathValueDetector. For each unique value extracted by target_path, a tracking record is added to expected_values_dict.
+    NewMatchPathValueDetector. For each unique value extracted by target_path_list, a tracking record is added to expected_values_dict.
     It stores three numbers: the timestamp the extracted value was last seen, the maximum allowed gap between observations and the next
     alerting time when currently in error state. When in normal (alerting) state, the value is zero.
     """
 
-    def __init__(self, aminer_config, target_path, anomaly_event_handlers, persistence_id='Default', auto_include_flag=False,
+    def __init__(self, aminer_config, target_path_list, anomaly_event_handlers, persistence_id='Default', auto_include_flag=False,
                  default_interval=3600, realert_interval=86400, output_log_line=True):
         """
         Initialize the detector. This will also trigger reading or creation of persistence storage location.
-        @param target_path to extract a source identification value from each logatom.
+        @param target_path_list to extract a source identification value from each logatom.
         """
-        self.target_path = target_path
+        self.target_path_list = target_path_list
         self.anomaly_event_handlers = anomaly_event_handlers
         self.auto_include_flag = auto_include_flag
         self.default_interval = default_interval
@@ -57,24 +58,23 @@ class MissingMatchPathValueDetector(AtomHandlerInterface, TimeTriggeredComponent
         self.log_learned_values = 0
         self.log_new_learned_values = []
 
+        self.persistence_file_name = build_persistence_file_name(aminer_config, self.__class__.__name__, persistence_id)
         PersistenceUtil.add_persistable_component(self)
-        self.persistence_file_name = AMinerConfig.build_persistence_file_name(aminer_config, self.__class__.__name__, persistence_id)
         persistence_data = PersistenceUtil.load_json(self.persistence_file_name)
         self.expected_values_dict = {}
         if persistence_data is not None:
             for key in persistence_data:
                 value = persistence_data[key]
-                if self.target_path is not None:
-                    if value[3] != self.target_path:
-                        continue
-                elif self.target_path_list is not None:
-                    if value[3] not in self.target_path_list:
+                if self.target_path_list is not None:  # skipcq: PTC-W0048
+                    if value[3] != self.target_path_list:
                         continue
+                elif self.target_path_list is not None and value[3] not in self.target_path_list:
+                    continue
                 if value[1] != default_interval:
                     value[1] = default_interval
                     value[2] = value[0] + default_interval
                 self.expected_values_dict[key] = value
-            logging.getLogger(AMinerConfig.DEBUG_LOG_NAME).debug('%s loaded persistence data.', self.__class__.__name__)
+            logging.getLogger(DEBUG_LOG_NAME).debug('%s loaded persistence data.', self.__class__.__name__)
         self.analysis_string = 'Analysis.%s'
 
     def receive_atom(self, log_atom):
@@ -112,21 +112,30 @@ class MissingMatchPathValueDetector(AtomHandlerInterface, TimeTriggeredComponent
         # Always enforce persistence syncs from time to time, the timestamps in the records change even when no new hosts are added.
         if self.next_persist_time is None:
             self.next_persist_time = time.time() + self.aminer_config.config_properties.get(
-                AMinerConfig.KEY_PERSISTENCE_PERIOD, AMinerConfig.DEFAULT_PERSISTENCE_PERIOD)
+                KEY_PERSISTENCE_PERIOD, DEFAULT_PERSISTENCE_PERIOD)
         self.check_timeouts(timestamp, log_atom)
         self.log_success += 1
         return True
 
     def get_channel_key(self, log_atom):
         """Get the key identifying the channel this log_atom is coming from."""
-        match_element = log_atom.parser_match.get_match_dictionary().get(self.target_path)
-        if match_element is None:
-            return None
-        if isinstance(match_element.match_object, bytes):
-            affected_log_atom_values = match_element.match_object.decode()
-        else:
-            affected_log_atom_values = match_element.match_object
-        return self.target_path, str(affected_log_atom_values)
+        value_list = []
+        for target_path in self.target_path_list:
+            match = log_atom.parser_match.get_match_dictionary().get(target_path)
+            if match is None:
+                return None
+            matches = []
+            if isinstance(match, list):
+                matches = match
+            else:
+                matches.append(match)
+            for match in matches:
+                if isinstance(match.match_object, bytes):
+                    affected_log_atom_values = match.match_object.decode(AminerConfig.ENCODING)
+                else:
+                    affected_log_atom_values = match.match_object
+                value_list.append(str(affected_log_atom_values))
+        return self.target_path_list, str(value_list)
 
     def check_timeouts(self, timestamp, log_atom):
         """Check if there was any timeout on a channel, thus triggering event dispatching."""
@@ -172,27 +181,44 @@ class MissingMatchPathValueDetector(AtomHandlerInterface, TimeTriggeredComponent
                 affected_log_atom_values = []
                 for value, overdue_time, interval in missing_value_list:
                     e = {}
+                    try:
+                        if isinstance(value, list):
+                            data = []
+                            for val in value:
+                                if isinstance(val, bytes):
+                                    data.append(val.decode(AminerConfig.ENCODING))
+                                else:
+                                    data.append(val)
+                            data = str(data)
+                        else:
+                            if isinstance(value, bytes):
+                                data = value.decode(AminerConfig.ENCODING)
+                            else:
+                                data = repr(value)
+                    except UnicodeError:
+                        data = repr(value)
                     if self.__class__.__name__ == 'MissingMatchPathValueDetector':
-                        e['TargetPath'] = self.target_path
-                        message_part.append('  %s: %s overdue %ss (interval %s)' % (self.target_path, repr(value), overdue_time, interval))
+                        e['TargetPathList'] = self.target_path_list
+                        message_part.append('  %s: %s overdue %ss (interval %s)' % (self.target_path_list, data, overdue_time,
+                                            interval))
                     else:
                         target_paths = ''
                         for target_path in self.target_path_list:
                             target_paths += target_path + ', '
                         e['TargetPathList'] = self.target_path_list
-                        message_part.append('  %s: %s overdue %ss (interval %s)' % (target_paths[:-2], repr(value), overdue_time, interval))
+                        message_part.append('  %s: %s overdue %ss (interval %s)' % (target_paths[:-2], data, overdue_time, interval))
                     e['Value'] = str(value)
                     e['OverdueTime'] = str(overdue_time)
                     e['Interval'] = str(interval)
                     affected_log_atom_values.append(e)
-                analysis_component = {'AffectedLogAtomPathes': list(log_atom.parser_match.get_match_dictionary()),
+                analysis_component = {'AffectedLogAtomPaths': list(log_atom.parser_match.get_match_dictionary()),
                                       'AffectedLogAtomValues': affected_log_atom_values}
                 if self.output_log_line:
                     match_paths_values = {}
                     for match_path, match_element in log_atom.parser_match.get_match_dictionary().items():
                         match_value = match_element.match_object
                         if isinstance(match_value, bytes):
-                            match_value = match_value.decode()
+                            match_value = match_value.decode(AminerConfig.ENCODING)
                         match_paths_values[match_path] = match_value
                     analysis_component['ParsedLogAtom'] = match_paths_values
                 event_data = {'AnalysisComponent': analysis_component}
@@ -213,33 +239,33 @@ class MissingMatchPathValueDetector(AtomHandlerInterface, TimeTriggeredComponent
         # not sync immediately, that would make bulk calls to this method quite inefficient.
         if self.next_persist_time is None:
             self.next_persist_time = time.time() + self.aminer_config.config_properties.get(
-                AMinerConfig.KEY_PERSISTENCE_PERIOD, AMinerConfig.DEFAULT_PERSISTENCE_PERIOD)
+                KEY_PERSISTENCE_PERIOD, DEFAULT_PERSISTENCE_PERIOD)
 
     def remove_check_value(self, value):
         """Remove checks for given value."""
         del self.expected_values_dict[value]
-        logging.getLogger(AMinerConfig.DEBUG_LOG_NAME).debug('%s removed check value %s.', self.__class__.__name__, str(value))
+        logging.getLogger(DEBUG_LOG_NAME).debug('%s removed check value %s.', self.__class__.__name__, str(value))
 
-    def get_time_trigger_class(self):
+    def get_time_trigger_class(self):  # skipcq: PYL-R0201
         """Get the trigger class this component can be registered for. This detector only needs persisteny triggers in real time."""
         return AnalysisContext.TIME_TRIGGER_CLASS_REALTIME
 
     def do_timer(self, trigger_time):
         """Check current ruleset should be persisted."""
         if self.next_persist_time is None:
-            return self.aminer_config.config_properties.get(AMinerConfig.KEY_PERSISTENCE_PERIOD, AMinerConfig.DEFAULT_PERSISTENCE_PERIOD)
+            return self.aminer_config.config_properties.get(KEY_PERSISTENCE_PERIOD, DEFAULT_PERSISTENCE_PERIOD)
         delta = self.next_persist_time - trigger_time
         if delta < 0:
             PersistenceUtil.store_json(self.persistence_file_name, self.expected_values_dict)
             self.next_persist_time = None
-            delta = self.aminer_config.config_properties.get(AMinerConfig.KEY_PERSISTENCE_PERIOD, AMinerConfig.DEFAULT_PERSISTENCE_PERIOD)
+            delta = self.aminer_config.config_properties.get(KEY_PERSISTENCE_PERIOD, DEFAULT_PERSISTENCE_PERIOD)
         return delta
 
     def do_persist(self):
         """Immediately write persistence data to storage."""
         PersistenceUtil.store_json(self.persistence_file_name, self.expected_values_dict)
         self.next_persist_time = None
-        logging.getLogger(AMinerConfig.DEBUG_LOG_NAME).debug('%s persisted data.', self.__class__.__name__)
+        logging.getLogger(DEBUG_LOG_NAME).debug('%s persisted data.', self.__class__.__name__)
 
     def allowlist_event(self, event_type, event_data, allowlisting_data):
         """
@@ -248,11 +274,11 @@ class MissingMatchPathValueDetector(AtomHandlerInterface, TimeTriggeredComponent
         """
         if event_type != self.analysis_string % self.__class__.__name__:
             msg = 'Event not from this source'
-            logging.getLogger(AMinerConfig.DEBUG_LOG_NAME).error(msg)
+            logging.getLogger(DEBUG_LOG_NAME).error(msg)
             raise Exception(msg)
         if not isinstance(allowlisting_data, int):
             msg = 'Allowlisting data has to integer with new interval, -1 to reset to defaults, other negative value to remove the entry'
-            logging.getLogger(AMinerConfig.DEBUG_LOG_NAME).error(msg)
+            logging.getLogger(DEBUG_LOG_NAME).error(msg)
             raise Exception(msg)
         new_interval = allowlisting_data
         if new_interval == -1:
@@ -268,11 +294,11 @@ class MissingMatchPathValueDetector(AtomHandlerInterface, TimeTriggeredComponent
         Log statistics of an AtomHandler. Override this method for more sophisticated statistics output of the AtomHandler.
         @param component_name the name of the component which is printed in the log line.
         """
-        if STAT_LEVEL == 1:
+        if AminerConfig.STAT_LEVEL == 1:
             logging.getLogger(STAT_LOG_NAME).info(
                 "'%s' processed %d out of %d log atoms successfully and learned %d new values in the last 60"
                 " minutes.", component_name, self.log_success, self.log_total, self.log_learned_values)
-        elif STAT_LEVEL == 2:
+        elif AminerConfig.STAT_LEVEL == 2:
             logging.getLogger(STAT_LOG_NAME).info(
                 "'%s' processed %d out of %d log atoms successfully and learned %d new values in the last 60"
                 " minutes. Following new values were learned: %s", component_name, self.log_success, self.log_total,
@@ -286,21 +312,11 @@ class MissingMatchPathValueDetector(AtomHandlerInterface, TimeTriggeredComponent
 class MissingMatchPathListValueDetector(MissingMatchPathValueDetector):
     """
     This detector works similar to the MissingMatchPathValueDetector.
-    It only can lookup values from a list of pathes until one path really exists. It then uses this value as key to detect logAtoms
+    It only can lookup values from a list of paths until one path really exists. It then uses this value as key to detect logAtoms
     belonging to the same data stream. This is useful when e.g. due to different log formats, the hostname, servicename or any other
-    relevant channel identifier has alternative pathes.
+    relevant channel identifier has alternative paths.
     """
 
-    def __init__(self, aminer_config, target_path_list, anomaly_event_handlers, persistence_id='Default', auto_include_flag=False,
-                 default_interval=3600, realert_interval=86400, output_log_line=True):
-        """
-        Initialize the detector. This will also trigger reading or creation of persistence storage location.
-        @param target_path to extract a source identification value from each logatom.
-        """
-        self.target_path_list = target_path_list
-        super(MissingMatchPathListValueDetector, self).__init__(aminer_config, None, anomaly_event_handlers, persistence_id,
-                                                                auto_include_flag, default_interval, realert_interval, output_log_line)
-
     def get_channel_key(self, log_atom):
         """Get the key identifying the channel this log_atom is coming from."""
         for target_path in self.target_path_list:
@@ -308,7 +324,7 @@ class MissingMatchPathListValueDetector(MissingMatchPathValueDetector):
             if match_element is None:
                 continue
             if isinstance(match_element.match_object, bytes):
-                affected_log_atom_values = match_element.match_object.decode()
+                affected_log_atom_values = match_element.match_object.decode(AminerConfig.ENCODING)
             else:
                 affected_log_atom_values = match_element.match_object
             return target_path, str(affected_log_atom_values)
