@@ -21,12 +21,12 @@ import sys
 import abc
 import logging
 
-from aminer.util import LogarithmicBackoffHistory
-from aminer.util import ObjectHistory
+from aminer.util.History import LogarithmicBackoffHistory
+from aminer.util.History import ObjectHistory
 
 from aminer.analysis.AtomFilters import SubhandlerFilter
-from aminer import AMinerConfig
-from aminer.AMinerConfig import STAT_LEVEL, STAT_LOG_NAME
+from aminer.AminerConfig import DEBUG_LOG_NAME, STAT_LOG_NAME
+from aminer import AminerConfig
 
 result_string = '%s(%s)'
 
@@ -87,7 +87,7 @@ class MatchRule(metaclass=abc.ABCMeta):
 
     def log_statistics(self, rule_id):
         """Log statistics of an MatchRule. Override this method for more sophisticated statistics output of the MatchRule."""
-        if STAT_LEVEL > 0:
+        if AminerConfig.STAT_LEVEL > 0:
             logging.getLogger(STAT_LOG_NAME).info("Rule '%s' processed %d out of %d log atoms successfully in the last 60"
                                                   " minutes.", rule_id, self.log_success, self.log_total)
         self.log_success = 0
@@ -225,9 +225,9 @@ class ValueDependentDelegatedMatchRule(MatchRule):
     def __init__(self, value_path_list, rule_lookup_dict, default_rule=None, match_action=None):
         """
         Create the rule.
-        @param list with value pathes that are used to extract the lookup keys for ruleLookupDict. If value lookup fails, None
+        @param list with value paths that are used to extract the lookup keys for ruleLookupDict. If value lookup fails, None
         will be used for lookup.
-        @param rule_lookup_dict dicitionary with tuple containing values for valuePathList as key and target rule as value.
+        @param rule_lookup_dict dictionary with tuple containing values for valuePathList as key and target rule as value.
         @param default_rule when not none, this rule will be executed as default. Otherwise when rule lookup failed, False will
         be returned unconditionally.
         @param match_action if None, no action is performed.
@@ -246,12 +246,14 @@ class ValueDependentDelegatedMatchRule(MatchRule):
         match_dict = log_atom.parser_match.get_match_dictionary()
         value_list = []
         for path in self.value_path_list:
-            value_element = match_dict.get(path, None)
-            if value_element is None:
-                value_list.append(None)
-            else:
+            value_element = match_dict.get(path)
+            if value_element is not None:
                 value_list.append(value_element.match_object)
-        rule = self.rule_lookup_dict.get(tuple(value_list), self.default_rule)
+        if len(value_list) > 0:
+            value = tuple(value_list)
+        else:
+            value = None
+        rule = self.rule_lookup_dict.get(value, self.default_rule)
         if rule is None:
             return False
         if rule.match(log_atom):
@@ -349,7 +351,7 @@ class ValueListMatchRule(MatchRule):
     def match(self, log_atom):
         """Check if this rule matches. On match an optional match_action could be triggered."""
         self.log_total += 1
-        test_value = log_atom.parser_match.get_match_dictionary().get(self.path, None)
+        test_value = log_atom.parser_match.get_match_dictionary().get(self.path)
         if (test_value is not None) and (test_value.match_object in self.value_list):
             if self.match_action is not None:
                 self.match_action.match_action(log_atom)
@@ -486,12 +488,15 @@ class ValueDependentModuloTimeMatchRule(MatchRule):
         match_dict = log_atom.parser_match.get_match_dictionary()
         value_list = []
         for path in self.value_path_list:
-            value_element = match_dict.get(path, None)
-            if value_element is None:
-                value_list.append(None)
-            else:
+            value_element = match_dict.get(path)
+            if value_element is not None:
                 value_list.append(value_element.match_object)
-        limits = self.limit_lookup_dict.get(value_list[0], self.default_limit)
+
+        if len(value_list) > 0:
+            value = value_list[0]
+        else:
+            value = None
+        limits = self.limit_lookup_dict.get(value, self.default_limit)
         if limits is None:
             return False
 
@@ -528,7 +533,7 @@ class IPv4InRFC1918MatchRule(MatchRule):
     def match(self, log_atom):
         """Check if this rule matches. On match an optional match_action could be triggered."""
         self.log_total += 1
-        match_element = log_atom.parser_match.get_match_dictionary().get(self.path, None)
+        match_element = log_atom.parser_match.get_match_dictionary().get(self.path)
         if (match_element is None) or not isinstance(match_element.match_object, int):
             return False
         value = match_element.match_object
@@ -583,7 +588,7 @@ class DebugHistoryMatchRule(MatchRule):
             object_history = LogarithmicBackoffHistory(10)
         elif not isinstance(object_history, ObjectHistory):
             msg = 'object_history is not an instance of ObjectHistory'
-            logging.getLogger(AMinerConfig.DEBUG_LOG_NAME).error(msg)
+            logging.getLogger(DEBUG_LOG_NAME).error(msg)
             raise Exception(msg)
         self.object_history = object_history
         self.debug_match_result = debug_match_result
